/*
 * Copyright 2004 Mns Tnneryd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.tanneryd.soapclipse.java2wsdl;

import org.eclipse.core.internal.utils.Assert;
import org.eclipse.jface.dialogs.IDialogSettings;

/**
 * @author Mns Tnneryd
 * 
Details:
   portType element name= <--portTypeName value> OR 
   binding  element name= <--bindingName value> OR <--servicePortName value>SoapBinding
   service  element name= <--serviceElementName value> OR <--portTypeName value>
Service
   port     element name= <--servicePortName value>
   address location     = <--location value>
*/
public class Java2WSDLDialogSettings
{
	private IDialogSettings dialogSettings;

	// Page 1
	private String outputWSDL; 				// output WSDL filename
	private String location; 				// service location url
	private String namespace; 				// target namespace
	private String pkgToNS; 				// package=namespace, name value pairs

	// Page 2
	private String inputWSDL; 				// input WSDL filename
	private String portTypeName; 			// portType name (obtained from 
											// class-of-portType if not specified)
	private String servicePortName; 		// service port name 
											// (obtained from --location if not specified)
	private String bindingName; 			// binding name 
											// (--servicePortName value + "SOAPBinding"
											// if not specified)
	private String serviceElementName; 		// service element name 
											// (defaults to --servicePortName value +
											// "Service")
	private String methods; 				// space or comma separated list of methods 
											// to export
	private boolean all; 					// look for allowed methods in inherited class
	private String outputWsdlMode;			// output WSDL mode: All, Interface, Implementation
	private String locationImport; 			// location of interface wsdl
	private String namespaceImpl; 			// target namespace for implementation wsdl
	private String outputImpl; 				// output Implementation WSDL filename, setting 
											// this causes --outputWsdlMode to be ignored
	private String implClass; 				// optional class that contains implementation  
											// of methods in class-of-portType.  The debug 
											// information in the class is used to obtain the 
											// method parameter names, which are used to set
											// the WSDL part names.
	private String exclude;					// space or comma separated list of methods 
											// not to export. 
	private String stopClasses; 			// space or comma separated list of class names
											// which will stop inheritance search if --all 
											// switch is given
	private String typeMappingVersion;		// indicate 1.1 or 1.2.  The default is 1.1
											// (SOAP 1.1 JAX-RPC compliant  1.2 indicates 
											// SOAP 1.1 encoded.)
	private String soapAction; 				// value of the operation's soapAction field. 
											// Values are DEFAULT, OPERATION or NONE. 
											// OPERATION forces soapAction to the name 
											// of the operation.  DEFAULT causes the soapAction
											// to be set according to the operation's meta 
											// data (usually "").  NONE	forces the soapAction 
											// to "".  The default is DEFAULT.
	private String style;					// The style of binding in the WSDL, either DOCUMENT,
											// RPC, or WRAPPED.
	private String use;						// The use of items in the binding, either LITERAL 
											// or ENCODED
	private String extraClasses;			// A space or comma separated list of class names
											// to be added to the type section.
	private String importSchema;			// A file or URL to an XML Schema that should be
											// physically imported into the generated WSDL
	private String classpath;			 	// additional classpath elements

	/**
	 *
	 */
	public Java2WSDLDialogSettings(IDialogSettings dialogSettings)
	{
		super();
		Assert.isLegal(null != dialogSettings);
		this.dialogSettings = dialogSettings;
		initialize();
	}

	void initialize()
	{
	}

	/**
	 * Store the current settings.
	 *
	 */
	void storeSettings()
	{
		dialogSettings.put( "inputWSDL", inputWSDL );
		dialogSettings.put( "outputWSDL", outputWSDL );
		dialogSettings.put( "location", location );
		dialogSettings.put( "portTypeName", portTypeName );
		dialogSettings.put( "bindingName", bindingName );
		dialogSettings.put( "serviceElementName", serviceElementName );
		dialogSettings.put( "servicePortName", servicePortName );
		dialogSettings.put( "namespace", namespace );
		dialogSettings.put( "pkgToNS", pkgToNS );
		dialogSettings.put( "methods", methods );
		dialogSettings.put( "all", all );
		dialogSettings.put( "outputWsdlMode", outputWsdlMode );
		dialogSettings.put( "locationImport", locationImport );
		dialogSettings.put( "namespaceImpl", namespaceImpl );
		dialogSettings.put( "outputImpl", outputImpl );
		dialogSettings.put( "implClass", implClass );
		dialogSettings.put( "exclude", exclude );
		dialogSettings.put( "stopClasses", stopClasses );
		dialogSettings.put( "typeMappingVersion", typeMappingVersion );
		dialogSettings.put( "soapAction", soapAction );
		dialogSettings.put( "style", style );
		dialogSettings.put( "use", use );
		dialogSettings.put( "extraClasses", extraClasses );
		dialogSettings.put( "importSchema", importSchema );
		dialogSettings.put( "classpath", classpath );
	}

	/**
	 * @return
	 */
	public boolean getAll()
	{
		return all;
	}

	/**
	 * @return
	 */
	public String getBindingName()
	{
		return bindingName;
	}

	/**
	 * @return
	 */
	public String getClasspath()
	{
		return classpath;
	}

	/**
	 * @return
	 */
	public IDialogSettings getDialogSettings()
	{
		return dialogSettings;
	}

	/**
	 * @return
	 */
	public String getExclude()
	{
		return exclude;
	}

	/**
	 * @return
	 */
	public String getExtraClasses()
	{
		return extraClasses;
	}

	/**
	 * @return
	 */
	public String getImplClass()
	{
		return implClass;
	}

	/**
	 * @return
	 */
	public String getImportSchema()
	{
		return importSchema;
	}

	/**
	 * @return
	 */
	public String getInputWSDL()
	{
		return inputWSDL;
	}

	/**
	 * @return
	 */
	public String getLocation()
	{
		return location;
	}

	/**
	 * @return
	 */
	public String getLocationImport()
	{
		return locationImport;
	}

	/**
	 * @return
	 */
	public String getMethods()
	{
		return methods;
	}

	/**
	 * @return
	 */
	public String getNamespace()
	{
		return namespace;
	}

	/**
	 * @return
	 */
	public String getNamespaceImpl()
	{
		return namespaceImpl;
	}

	/**
	 * @return
	 */
	public String getOutputImpl()
	{
		return outputImpl;
	}

	/**
	 * @return
	 */
	public String getOutputWSDL()
	{
		return outputWSDL;
	}

	/**
	 * @return
	 */
	public String getOutputWsdlMode()
	{
		return outputWsdlMode;
	}

	/**
	 * @return
	 */
	public String getPkgToNS()
	{
		return pkgToNS;
	}

	/**
	 * @return
	 */
	public String getPortTypeName()
	{
		return portTypeName;
	}

	/**
	 * @return
	 */
	public String getServiceElementName()
	{
		return serviceElementName;
	}

	/**
	 * @return
	 */
	public String getServicePortName()
	{
		return servicePortName;
	}

	/**
	 * @return
	 */
	public String getSoapAction()
	{
		return soapAction;
	}

	/**
	 * @return
	 */
	public String getStopClasses()
	{
		return stopClasses;
	}

	/**
	 * @return
	 */
	public String getStyle()
	{
		return style;
	}

	/**
	 * @return
	 */
	public String getTypeMappingVersion()
	{
		return typeMappingVersion;
	}

	/**
	 * @return
	 */
	public String getUse()
	{
		return use;
	}

	/**
	 * @param string
	 */
	public void setAll(boolean all)
	{
		this.all = all;
	}

	/**
	 * @param string
	 */
	public void setBindingName(String string)
	{
		bindingName = string;
	}

	/**
	 * @param string
	 */
	public void setClasspath(String string)
	{
		classpath = string;
	}

	/**
	 * @param settings
	 */
	public void setDialogSettings(IDialogSettings settings)
	{
		dialogSettings = settings;
	}

	/**
	 * @param string
	 */
	public void setExclude(String string)
	{
		exclude = string;
	}

	/**
	 * @param string
	 */
	public void setExtraClasses(String string)
	{
		extraClasses = string;
	}

	/**
	 * @param string
	 */
	public void setImplClass(String string)
	{
		implClass = string;
	}

	/**
	 * @param string
	 */
	public void setImportSchema(String string)
	{
		importSchema = string;
	}

	/**
	 * @param string
	 */
	public void setInputWSDL(String string)
	{
		inputWSDL = string;
	}

	/**
	 * @param string
	 */
	public void setLocation(String string)
	{
		location = string;
	}

	/**
	 * @param string
	 */
	public void setLocationImport(String string)
	{
		locationImport = string;
	}

	/**
	 * @param string
	 */
	public void setMethods(String string)
	{
		methods = string;
	}

	/**
	 * @param string
	 */
	public void setNamespace(String string)
	{
		namespace = string;
	}

	/**
	 * @param string
	 */
	public void setNamespaceImpl(String string)
	{
		namespaceImpl = string;
	}

	/**
	 * @param string
	 */
	public void setOutputImpl(String string)
	{
		outputImpl = string;
	}

	/**
	 * @param string
	 */
	public void setOutputWSDL(String string)
	{
		outputWSDL = string;
	}

	/**
	 * @param string
	 */
	public void setOutputWsdlMode(String string)
	{
		outputWsdlMode = string;
	}

	/**
	 * @param string
	 */
	public void setPkgToNS(String string)
	{
		pkgToNS = string;
	}

	/**
	 * @param string
	 */
	public void setPortTypeName(String string)
	{
		portTypeName = string;
	}

	/**
	 * @param string
	 */
	public void setServiceElementName(String string)
	{
		serviceElementName = string;
	}

	/**
	 * @param string
	 */
	public void setServicePortName(String string)
	{
		servicePortName = string;
	}

	/**
	 * @param string
	 */
	public void setSoapAction(String string)
	{
		soapAction = string;
	}

	/**
	 * @param string
	 */
	public void setStopClasses(String string)
	{
		stopClasses = string;
	}

	/**
	 * @param string
	 */
	public void setStyle(String string)
	{
		style = string;
	}

	/**
	 * @param string
	 */
	public void setTypeMappingVersion(String string)
	{
		typeMappingVersion = string;
	}

	/**
	 * @param string
	 */
	public void setUse(String string)
	{
		use = string;
	}

}
