/*
 * Copyright 2004 Mns Tnneryd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.tanneryd.soapclipse.java2wsdl;

import java.net.URL;
import java.net.URLClassLoader;
import java.util.HashMap;

import org.apache.axis.wsdl.fromJava.Emitter;
import org.eclipse.core.resources.IFile;
import org.eclipse.jdt.core.IJavaProject;
import org.eclipse.jdt.core.IPackageDeclaration;
import org.eclipse.jface.wizard.Wizard;
import org.apache.log4j.Logger;

import com.tanneryd.soapclipse.SoapClipsePlugin;

/**
 * @author Mns Tnneryd
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
public class Java2WSDLWizard extends Wizard
{
	static Logger logger = Logger.getLogger(Java2WSDLWizard.class.getName());

	private Java2WSDLDialogSettings dialogSettings;
	private Java2WSDLWizardPage1 page1;
	private Java2WSDLWizardPage2 page2;
	private IFile selectedFile;
	private IPackageDeclaration selectedPackage;
	private IJavaProject javaProject;

	public Java2WSDLWizard(
		IFile selectedFile,
		IPackageDeclaration selectedPackage,
		IJavaProject javaProject)
	{
		this.selectedFile = selectedFile;
		this.selectedPackage = selectedPackage;
		this.javaProject = javaProject;

		this.dialogSettings =
			new Java2WSDLDialogSettings(
				SoapClipsePlugin.getDefault().getDialogSettings());
		page1 = new Java2WSDLWizardPage1(dialogSettings, selectedFile, javaProject);
		page2 = new Java2WSDLWizardPage2(dialogSettings, selectedFile, page1);

		addPage(page1);
		addPage(page2);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.IWizard#performFinish()
	 */
	public boolean performFinish()
	{
		try
		{
			page1.storeSettings();
			page2.storeSettings();
			dialogSettings.storeSettings();

			runEmitter();
			return true;
		}
		catch (Exception e)
		{
			e.printStackTrace();
		}

		return false;
	}

	/*
	 * 
	 */
	//	Emitter emitter = new Emitter();
	//
	//	String classFilename = selectedFile.getName();
	//		
	//	URLClassLoader cl = new URLClassLoader(
	//		new URL[] { new URL("file:/E:\\runtime-workspace\\PluginTestProject\\bin\\")});
	//	Thread t = Thread.currentThread();
	//	t.setContextClassLoader(cl);
	//		
	//	String packageName = selectedPackage.getElementName();
	//	String className = selectedFile.getName().split("\\.")[0];
	//	emitter.setCls(packageName + "." + className);
	//	emitter.setLocationUrl("http://www.tanneryd.com:8080/axis/services/VersionService");
	//	emitter.setPortTypeName( className + "PortType" );
	//	emitter.emit("E:\\runtime-workspace\\PluginTestProject\\VersionService.wsdl");

	/**
	 * I can't beleive it has to be this backwards to get the
	 * file system path to a project directory...
	 */
	private String getProjectOutputLocation() throws Exception
	{
		String workspaceLocation = javaProject.getProject().getLocation().removeLastSegments(1).toOSString();
		String relativeOutputLocation = javaProject.getOutputLocation().toOSString();
		String absoluteOutputLocation = workspaceLocation + relativeOutputLocation;
		
		return absoluteOutputLocation;
	}
	
	private void runEmitter() throws Exception
	{
		Emitter emitter = new Emitter();
		
		// Configure the emitter with values from page 1
		emitter.setLocationUrl(dialogSettings.getLocation());

		String portTypeName = dialogSettings.getPortTypeName();
		if ( portTypeName != null && !portTypeName.equals(""))
			emitter.setPortTypeName( portTypeName );
		
		String namespace = dialogSettings.getNamespace();
		if ( namespace != null && !namespace.equals(""))
			emitter.setIntfNamespace( namespace );
		
		String pkgToNS = dialogSettings.getPkgToNS();
		if ( pkgToNS != null && pkgToNS.indexOf("=") >= 0)
		{
			String[] s = pkgToNS.split("=");
			HashMap m = new HashMap();
			m.put(s[0], s[1]);
			emitter.setNamespaceMap(m);
		}

		// Configure the emitter with values from page 2
		String inputWSDL = dialogSettings.getInputWSDL();
		if ( inputWSDL != null && !inputWSDL.equals(""))
			emitter.setInputWSDL( inputWSDL );
		
		String bindingName = dialogSettings.getBindingName();
		if ( bindingName != null && !bindingName.equals(""))
			emitter.setBindingName( bindingName );
		

		// Make sure we can see our compiled class
			URLClassLoader cl = 
			new URLClassLoader(
				new URL[] {	new URL( "file:/" + getProjectOutputLocation() + "\\" ) });
		Thread t = Thread.currentThread();
		t.setContextClassLoader(cl);

		String packageName = selectedPackage.getElementName();
		String className = selectedFile.getName().split("\\.")[0];
		emitter.setCls(packageName + "." + className);
		
		logger.debug("Generating " + dialogSettings.getOutputWSDL());
		emitter.emit( dialogSettings.getOutputWSDL() );
	}
}
