/*
 * Copyright 2004 Mns Tnneryd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.tanneryd.soapclipse.java2wsdl;

import org.eclipse.core.resources.IFile;
import org.eclipse.jdt.core.IJavaProject;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.FileDialog;
import org.eclipse.swt.widgets.Text;

import com.tanneryd.soapclipse.SoapClipseTools;

/**
 * @author Mns Tnneryd
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
public class Java2WSDLWizardPage1 extends WizardPage
{
	private Combo comboTypeMapping;
	private Button chkSafePassword;
	private ISelection selection;
	private Text outputWSDL;
	private Text location;
	private Text portTypeName;
	private Text namespace;
	private Text pkgToNSMappings;
	private IFile javaFile;
	private IJavaProject javaProject;

	private Java2WSDLDialogSettings dialogSettings;

	public Java2WSDLWizardPage1(
		Java2WSDLDialogSettings dialogSettings,
		IFile javaFile,
		IJavaProject javaProject)
	{
		super("Page1");
		this.dialogSettings = dialogSettings;
		this.javaFile = javaFile;
		this.javaProject = javaProject;

		setTitle("General settings");
		setDescription(
			"This wizard creates a WSDL file from a java class "
				+ "using Apache Axis Java2WSDL.");
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
	 */
	public void createControl(Composite parent)
	{
		Composite container = new Composite(parent, SWT.NULL);
		GridLayout layout = new GridLayout();
		container.setLayout(layout);
		layout.numColumns = 4;
		layout.makeColumnsEqualWidth = true;
		layout.verticalSpacing = 8;

		addOutputWSDLItems(container);

		addServiceLocationItems(container);

		portTypeName =
			SoapClipseTools.addTextInputItems(
				container,
				3,
				"PortType name:",
				"Indicates the name to use for the portType element. \n"
					+ "The default value used for this field by the java2wsdl emitter \n"
					+ "is the name of the java file beeing processed. When running \n"
					+ "wsdl2java the port type name is used to generate an interface file \n"
					+ "containing the methods of your processed java class. Unfortunatly \n"
					+ "that would overwrite your original java class. So, unless you \n"
					+ "specify a value for the port type name different from your original \n"
					+ "java class it will be overwritten. This, ofcourse, is just fine if \n"
					+ "you are generating a wsdl file from an interface file you intend to \n"
					+ "implement in your service implementation, but if you are trying to \n"
					+ "export methods from an existing java class as a web service it would \n"
					+ "be a whole lot less appropriate.");

		namespace =
			SoapClipseTools.addTextInputItems(
				container,
				3,
				"Target namespace:",
				"The target namespace of the WSDL file.");

		pkgToNSMappings =
			SoapClipseTools.addTextInputItems(
				container,
				3,
				"Package to namspace mappings:",
				"Indicates a mapping from the package to a namespace. "
					+ "There may be multiple mappings. The class specified "
					+ "contains the interface of the webservice.");

		loadSettings();
		validate();
		setControl(container);
	}

	private void addOutputWSDLItems(Composite container)
	{
		outputWSDL =
			SoapClipseTools.addTextInputItems(
				container,
				2,
				"Output WSDL file:",
				"The name of the output WSDL file.");

		outputWSDL.addModifyListener(new ModifyListener()
		{
			public void modifyText(ModifyEvent e)
			{
				validate();
			}
		});

		Button button = new Button(container, SWT.PUSH);
		button.setText("Browse...");
		button.setToolTipText("Select output file location.");
		button.setLayoutData(new GridData(GridData.END));
		button.addSelectionListener(new SelectionAdapter()
		{
			public void widgetSelected(SelectionEvent e)
			{
				handleBrowse(outputWSDL);
			}
		});
	}

	private void addServiceLocationItems(Composite container)
	{
		location =
			SoapClipseTools.addTextInputItems(
				container,
				3,
				"Service location (url):",
				"The location (url) of the service.");

		location.addModifyListener(new ModifyListener()
		{
			public void modifyText(ModifyEvent e)
			{
				validate();
			}
		});
	}

	private void loadSettings()
	{
		String className =
			javaFile.getName().substring(0, javaFile.getName().indexOf("."));
		String defaultServiceName = className + "Service";
		String defaultPortTypeName = className + "PortType";

		String defaultPath =
			SoapClipseTools.toFileSystemPath(
				javaProject.getPath().toOSString());
		String defaultWSDLFilename =
			defaultPath + "\\" + defaultServiceName + ".wsdl";
		SoapClipseTools.loadTextSetting(
			outputWSDL,
			dialogSettings.getOutputWSDL(),
			defaultWSDLFilename);

		String defaultLocation =
			"http://localhost:8080/axis/services/" + defaultServiceName;
		SoapClipseTools.loadTextSetting(
			location,
			dialogSettings.getLocation(),
			defaultLocation);

		SoapClipseTools.loadTextSetting(
			portTypeName,
			dialogSettings.getPortTypeName(),
			defaultPortTypeName);
		SoapClipseTools.loadTextSetting(
			namespace,
			dialogSettings.getNamespace(),
			null);
		SoapClipseTools.loadTextSetting(
			pkgToNSMappings,
			dialogSettings.getPkgToNS(),
			null);
	}

	public void storeSettings()
	{
		dialogSettings.setOutputWSDL(outputWSDL.getText());
		dialogSettings.setLocation(location.getText());
		dialogSettings.setPortTypeName(portTypeName.getText());
		dialogSettings.setNamespace(namespace.getText());
		dialogSettings.setPkgToNS(pkgToNSMappings.getText());
	}

	/**
	 * Uses the standard container selection dialog to
	 * choose the new value for the container field.
	 */
	private void handleBrowse(Text outputWSDL)
	{
		FileDialog dialog = new FileDialog(getShell());

		dialog.setFileName(outputWSDL.getText());
		String filename = dialog.open();
		if (filename != null)
			outputWSDL.setText(filename);
	}

	/**
	 * 
	 * 
	 */
	private void updateStatus(String message)
	{
		setErrorMessage(message);
		setPageComplete(message == null);
	}

	/**
	 * Ensures that both text fields are set.
	 */
	private void validate()
	{

		if (outputWSDL.getText().length() == 0)
		{
			updateStatus("Output wsdl filename must be set.");
			return;
		}
		if (location.getText().length() == 0)
		{
			updateStatus("Service location must be set.");
			return;
		}
		if (portTypeName.getText().length() == 0)
		{
			updateStatus("Port type name must be set.");
			return;
		}

		// updateStatus with null enables the next page 
		updateStatus(null);
	}
	
	/**
	 * @return
	 */
	public String getPortTypeName()
	{
		return portTypeName.getText();
	}

	/**
	 * @return
	 */
	public String getLocation()
	{
		return location.getText();
	}
}
