/*
 * Copyright 2004 Mns Tnneryd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package com.tanneryd.soapclipse.java2wsdl;

import org.eclipse.core.resources.IFile;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Text;

import com.tanneryd.soapclipse.SoapClipseTools;

/**
 * @author Mns Tnneryd
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
public class Java2WSDLWizardPage2 extends WizardPage
{
	private Java2WSDLWizard wizard;
	private Text inputWSDL;
	
	private Text servicePortName;
	private boolean servicePortNameModified = false;

	private Text bindingName; 
	private boolean bindingNameModified = false;
	
	private Text serviceElementName;
	private boolean serviceElementNameModified = false;
	
	private Text methods;
	private Button chkAll;
	private Combo comboOutputWSDLMode;
	
	private Java2WSDLDialogSettings dialogSettings;
	private IFile javaFile;
	private Java2WSDLWizardPage1 page1;

	public Java2WSDLWizardPage2(
		Java2WSDLDialogSettings dialogSettings,
		IFile javaFile,
		Java2WSDLWizardPage1 page1)
	{
		super("Page2");
		this.dialogSettings = dialogSettings;
		this.javaFile = javaFile;
		this.page1 = page1;

		setTitle("Advanced settings");
		setDescription(
			"This wizard creates a WSDL file from a java class "
				+ "using Apache Axis Java2WSDL.");

	}

	/**
	 * @see IDialogPage#createControl(Composite)
	 */
	public void createControl(Composite parent)
	{
		this.wizard = (Java2WSDLWizard) this.getWizard();

		Composite container = new Composite(parent, SWT.NULL);
		GridLayout layout = new GridLayout();
		container.setLayout(layout);
		layout.numColumns = 3;
		layout.verticalSpacing = 6;

		// Advanced options
		inputWSDL =
			SoapClipseTools.addTextInputItems(
				container,
				2,
				"Input WSDL:",
				"Input WSDL filename.");
				
		servicePortName =
			SoapClipseTools.addTextInputItems(
				container,
				2,
				"Service port name:",
				"Obtained from location if not specified.");
		servicePortName.addModifyListener(new ModifyListener()
		{
			public void modifyText(ModifyEvent e)
			{
				servicePortNameModified = true;
			}
		});
		
		bindingName =
			SoapClipseTools.addTextInputItems(
				container,
				2,
				"Binding name:",
				"Indicates the name to use for the binding element. "
					+ "Defaults to service port name value + 'SoapBinding'.");
		bindingName.addModifyListener(new ModifyListener()
		{
			public void modifyText(ModifyEvent e)
			{
				bindingNameModified = true;
			}
		});
		
		serviceElementName =
			SoapClipseTools.addTextInputItems(
				container,
				2,
				"Service element name:",
				"Defaults to service port name value + 'Service'.");
		serviceElementName.addModifyListener(new ModifyListener()
		{
			public void modifyText(ModifyEvent e)
			{
				serviceElementNameModified = true;
			}
		});

		methods =
			SoapClipseTools.addTextInputItems(
				container,
				2,
				"Methods:",
				"Space or comma separated list of methods to export.");
		chkAll =
			SoapClipseTools.addCheckBoxItems(
				container,
				3,
				"Look for allowed methods in inherited class.");
		comboOutputWSDLMode =
			SoapClipseTools.addComboBoxItems(
				container,
				2,
				"Output WSDL mode:",
				new String[] { "All", "Interface", "Implementation" });

		loadSettings();
		validate();
		setControl(container);
	}

	/*
	 * The service port name defaults to the last
	 * component of location.
	 */
	private void loadServicePortName()
	{
		if (!servicePortNameModified )
		{
			String s[] = page1.getLocation().split("/");
			String defaultServicePortName = s[s.length - 1];

			SoapClipseTools.loadTextSetting(
				servicePortName,
				dialogSettings.getServicePortName(),
				defaultServicePortName);

			// The modify listener will trigger when we
			// set the textbox value. This is not what we
			// want. We only want to set the dirty flag
			// when the user makes a modification. Thus,
			// we reset the flag here, undoing the work
			// of the listener.
			servicePortNameModified = false;
		}
	}
	
	/*
	 * The binding name defaults to the port type name
	 * plus "SoapBinding"
	 */
	private void loadBindingName()
	{
		if (!bindingNameModified)
		{
			String defaultServiceBindingName =
				page1.getPortTypeName() + "SoapBinding";

			SoapClipseTools.loadTextSetting(
				bindingName,
				dialogSettings.getBindingName(),
				defaultServiceBindingName);

			// The modify listener will trigger when we
			// set the textbox value. This is not what we
			// want. We only want to set the dirty flag
			// when the user makes a modification. Thus,
			// we reset the flag here, undoing the work
			// of the listener.
			bindingNameModified = false;
		}
	}
	
	/*
	 * The service element name defaults to the port type name
	 * plus "Service"
	 */
	private void loadServiceElementName()
	{
		if (!serviceElementNameModified)
		{
			String defaultServiceElementName =
				page1.getPortTypeName() + "Service";
			SoapClipseTools.loadTextSetting(
				serviceElementName,
				dialogSettings.getServiceElementName(),
				defaultServiceElementName);
			
			// The modify listener will trigger when we
			// set the textbox value. This is not what we
			// want. We only want to set the dirty flag
			// when the user makes a modification. Thus,
			// we reset the flag here, undoing the work
			// of the listener.
			serviceElementNameModified = false;
		}
	}
	
	private void loadSettings()
	{
		SoapClipseTools.loadTextSetting(
			inputWSDL,
			dialogSettings.getInputWSDL());

		loadServicePortName();
		loadBindingName();
		loadServiceElementName();

		SoapClipseTools.loadTextSetting(methods, dialogSettings.getMethods());
	}

	public void storeSettings()
	{
		dialogSettings.setInputWSDL(inputWSDL.getText());
		dialogSettings.setBindingName(bindingName.getText());
		dialogSettings.setServiceElementName(serviceElementName.getText());
		dialogSettings.setServicePortName(servicePortName.getText());
		dialogSettings.setMethods(methods.getText());
	}

	private void updateStatus(String message)
	{
		setErrorMessage(message);
		setPageComplete(message == null);
	}

	/**
	 * Ensures that both text fields are set.
	 */
	private void validate()
	{
		//updateStatus with null enables the next page 
		updateStatus(null);
	}

	/* (non-Javadoc)
	 * 
	 * Catch the page as we move into it and update values dependent
	 * on previous pages.
	 * 
	 * @see org.eclipse.jface.dialogs.IDialogPage#setVisible(boolean)
	 */
	public void setVisible(boolean visible)
	{
		super.setVisible(visible);
		this.loadServicePortName();
		this.loadBindingName();
		this.loadServiceElementName();
	}

}
