/*
 * Copyright 2003 Andres Aguiar
 * Copyright 2003 Marco Ensing
 * Copyright 2004 Mns Tnneryd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */ 
package com.tanneryd.soapclipse.wsdl2java;

import org.eclipse.core.internal.utils.Assert;
import org.eclipse.jface.dialogs.IDialogSettings;

/**
 * @author Andres Aguiar
 * @author Marco Ensing
 */
public class WSDL2JavaDialogSettings
{
	private boolean all; // -a
	private String deployScope; // -d
	private IDialogSettings dialogSettings;
	private String factory;
	private String implementationClassName; // -c
	private String fileNStoPkg; // -f
	private boolean helperGen;
	private boolean noImports; // -n
	private boolean noWrapped; // -W
	private String NStoPkg;
	private String packageName; // -p
	private String password; // -P
	private boolean passwordSafe; //store the password from the wizard?
	private boolean serverSide; // -s
	private boolean skeletonDeploy; // -S
	private boolean testCase; // -t
	private int timeout; // -O
	private String typeMappingVersion;
	private String fileContainer;
	private String url;
	private String user; // -U

	/**
	 *
	 */
	public WSDL2JavaDialogSettings(IDialogSettings dialogSettings)
	{
		super();
		Assert.isLegal(null != dialogSettings);
		this.dialogSettings = dialogSettings;
		initialize();
	}

	public void setAll(boolean all)
	{
		this.all = all;
	}
	public boolean isAll()
	{
		return all;
	}

	public void setDeployScope(String deployScope)
	{
		this.deployScope =
			(deployScope.trim().length() == 0) ? null : deployScope;
	}
	public String getDeployScope()
	{
		return deployScope;
	}

	public void setFactory(String factory)
	{
		this.factory = (factory.trim().length() == 0) ? null : factory;
	}
	public String getFactory()
	{
		return factory;
	}

	public void setImplementationClassName(String classname)
	{
		this.implementationClassName = (classname.trim().length() == 0) ? null : classname;
	}
	
	public String getImplementationClassName()
	{
		return implementationClassName;
	}

	public void setFileContainer(String string)
	{
		fileContainer = string;
	}
	public String getFileContainer()
	{
		return fileContainer;
	}

	public void setFileNStoPkg(String fileNStoPkg)
	{
		this.fileNStoPkg =
			(fileNStoPkg.trim().length() == 0) ? null : fileNStoPkg;
	}
	public String getFileNStoPkg()
	{
		return fileNStoPkg;
	}

	public void setHelperGen(boolean helperGen)
	{
		this.helperGen = helperGen;
	}
	public boolean isHelperGen()
	{
		return helperGen;
	}

	public void setNStoPkg(String nStoPkg)
	{
		NStoPkg = (nStoPkg.trim().length() == 0) ? null : nStoPkg;
	}
	public String getNStoPkg()
	{
		return NStoPkg;
	}

	public void setNoImports(boolean noImports)
	{
		this.noImports = noImports;
	}
	public boolean isNoImports()
	{
		return noImports;
	}

	public void setNoWrapped(boolean noWrapped)
	{
		this.noWrapped = noWrapped;
	}
	public boolean isNoWrapped()
	{
		return noWrapped;
	}

	public void setPackageName(String packageName)
	{
		this.packageName =
			(packageName.trim().length() == 0) ? null : packageName;
	}
	public String getPackageName()
	{
		return packageName;
	}

	public void setPassword(String password)
	{
		this.password = (password.trim().length() == 0) ? null : password;
	}
	public String getPassword()
	{
		return password;
	}

	public void setPasswordSafe(boolean b)
	{
		passwordSafe = b;
	}
	public boolean isPasswordSafe()
	{
		return passwordSafe;
	}

	public void setServerSide(boolean serverSide)
	{
		this.serverSide = serverSide;
	}
	public boolean isServerSide()
	{
		return serverSide;
	}

	public void setSkeletonDeploy(boolean skeletonDeploy)
	{
		this.skeletonDeploy = skeletonDeploy;
	}
	public boolean isSkeletonDeploy()
	{
		return skeletonDeploy;
	}

	public void setTestCase(boolean testCase)
	{
		this.testCase = testCase;
	}
	public boolean isTestCase()
	{
		return testCase;
	}

	public void setTimeout(int timeout)
	{
		this.timeout = timeout;
	}
	public int getTimeout()
	{
		return timeout;
	}

	public void setTypeMappingVersion(String typeMappingVersion)
	{
		this.typeMappingVersion =
			(typeMappingVersion.trim().length() == 0)
				? null
				: typeMappingVersion;
	}
	public String getTypeMappingVersion()
	{
		return typeMappingVersion;
	}

	public void setUrl(String string)
	{
		url = string;
	}
	public String getUrl()
	{
		return url;
	}

	public void setUser(String user)
	{
		this.user = (user.trim().length() == 0) ? null : user;
	}
	public String getUser()
	{
		return user;
	}



	void initialize()
	{
		all = dialogSettings.getBoolean("all");
		deployScope = dialogSettings.get("deployScope");
		if (null == deployScope)
		{
			deployScope = "request";
		}
		factory = dialogSettings.get("factory");
		if (null == factory)
		{
			factory = "";
		}
		fileContainer = dialogSettings.get("fileContainer");
		if (null == fileContainer)
		{
			fileContainer = "";
		}
		fileNStoPkg = dialogSettings.get("fileNStoPkg");
		if (null == fileNStoPkg)
		{
			fileNStoPkg = "NStoPkg.properties";
		}
		helperGen = dialogSettings.getBoolean("helperGen");
		noImports = dialogSettings.getBoolean("noImports");
		noWrapped = dialogSettings.getBoolean("noWrapped");
		NStoPkg = dialogSettings.get("NStoPkg");
		if (null == NStoPkg)
		{
			NStoPkg = "";
		}
		packageName = dialogSettings.get("packageName");
		if (null == packageName)
		{
			packageName = "";
		}
		passwordSafe = dialogSettings.getBoolean("passwordSafe");
		if (passwordSafe)
		{
			password = dialogSettings.get("password");
		}
		if (null == password)
		{
			password = "";
		}

		serverSide = dialogSettings.getBoolean("serverSide");
		skeletonDeploy = dialogSettings.getBoolean("skeletonDeploy");
		testCase = dialogSettings.getBoolean("testCase");
		try
		{
			timeout = dialogSettings.getInt("timeout");
		}
		catch (NumberFormatException nfe)
		{
			timeout = -1;
		}
		typeMappingVersion = dialogSettings.get("typeMappingVersion");
		if (null == typeMappingVersion)
		{
			typeMappingVersion = "1.2";
		}
		user = dialogSettings.get("user");
		if (null == user)
		{
			user = "";
		}
		url = dialogSettings.get("url");
		if (null == url)
		{
			url = "http://www.xmethods.net/sd/2001/TemperatureService.wsdl";
		}
	}

	/**
	 * Store the current settings.
	 *
	 */
	void storeSettings()
	{
		dialogSettings.put("all", all);
		dialogSettings.put("deployScope", deployScope);
		dialogSettings.put("factory", factory);
		dialogSettings.put("fileNStoPkg", fileNStoPkg);
		dialogSettings.put("fileContainer", fileContainer);
		dialogSettings.put("helperGen", helperGen);
		dialogSettings.put("noImports", noImports);
		dialogSettings.put("noWrapped", noWrapped);
		dialogSettings.put("NStoPkg", NStoPkg);
		dialogSettings.put("packageName", packageName);
		dialogSettings.put("passwordSafe", passwordSafe);
		dialogSettings.put("password", password);
		dialogSettings.put("serverSide", serverSide);
		dialogSettings.put("skeletonDeploy", skeletonDeploy);
		dialogSettings.put("testCase", testCase);
		dialogSettings.put("timeout", timeout);
		dialogSettings.put("typeMappingVersion", typeMappingVersion);
		dialogSettings.put("user", user);
		dialogSettings.put("url", url);
	}
}
