/*
 * Copyright 2003 Andres Aguiar
 * Copyright 2003 Marco Ensing
 * Copyright 2004 Mns Tnneryd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */ 
package com.tanneryd.soapclipse.wsdl2java;

import org.apache.axis.wsdl.toJava.Emitter;
import org.eclipse.core.resources.IFile;
import org.eclipse.jface.wizard.Wizard;

import com.tanneryd.soapclipse.SoapClipsePlugin;
import com.tanneryd.soapclipse.SoapClipseTools;

/**
 * @author Andres Aguiar
 * @author Marco Ensing
 * @author Mns Tnneryd
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
public class WSDL2JavaWizard extends Wizard
{
	private WSDL2JavaDialogSettings dialogSettings;
	private WSDL2JavaWizardPage1 page1;
	private WSDL2JavaWizardPage2 page2;
	private IFile selectedFile;
	
	public WSDL2JavaWizard(IFile selectedFile)
	{
		this.selectedFile = selectedFile;
		this.dialogSettings =
			new WSDL2JavaDialogSettings(
				SoapClipsePlugin.getDefault().getDialogSettings());
		page1 =	new WSDL2JavaWizardPage1( dialogSettings, selectedFile );
		page2 =	new WSDL2JavaWizardPage2( dialogSettings, selectedFile );
			
		addPage(page1);
		addPage(page2);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.wizard.IWizard#performFinish()
	 */
	public boolean performFinish()
	{
		try
		{
			page1.storeSettings();
			page2.storeSettings();
			dialogSettings.storeSettings();
			
			runEmitter();
			return true;
		}
		catch(Exception e)
		{
			e.printStackTrace();
		}
		
		return false;
	}
	
	/*
	 * 
	 */
	private void runEmitter()
		throws Exception
	{
		Emitter emitter = new Emitter();

		emitter.setAllWanted(dialogSettings.isAll());

		if (dialogSettings.getFactory() != null)
		{
			emitter.setFactory(dialogSettings.getFactory());
		}
		
		if (dialogSettings.getImplementationClassName() != null)
		{
			emitter.setImplementationClassName(dialogSettings.getImplementationClassName());
		}

		emitter.setHelperWanted(dialogSettings.isHelperGen());
		emitter.setImports(dialogSettings.isNoImports());

		emitter.setNowrap(dialogSettings.isNoWrapped());

		if (dialogSettings.getNStoPkg() != null)
		{
			//emitter.setNStoPkg(new File(dialogSettings.getNStoPkg()));
			emitter.setNStoPkg(dialogSettings.getNStoPkg());
		}

		if (dialogSettings.getPackageName() != null)
		{
			emitter.setPackageName(dialogSettings.getPackageName());
		}

		if (dialogSettings.getPassword() != null)
		{
			emitter.setPassword(dialogSettings.getPassword());
		}

		emitter.setScope(
			org.apache.axis.enum.Scope.getScope(dialogSettings.getDeployScope()));
		emitter.setServerSide(dialogSettings.isServerSide());
		emitter.setSkeletonWanted(dialogSettings.isSkeletonDeploy());
		emitter.setTestCaseWanted(dialogSettings.isTestCase());

		// Convert timeout to milliseconds
		emitter.setTimeout(
			(dialogSettings.getTimeout() != -1) ? (dialogSettings.getTimeout() * 1000) : (-1));

		emitter.setTypeMappingVersion(dialogSettings.getTypeMappingVersion());
		if (dialogSettings.getUser() != null)
		{
			emitter.setUsername(dialogSettings.getUser());
		}

		
		String outputDirectory = SoapClipseTools.toFileSystemPath( dialogSettings.getFileContainer() );
	 	emitter.setOutputDir(outputDirectory);

	 	emitter.run(dialogSettings.getUrl());
	}
}
