/*
 * Copyright 2003 Andres Aguiar
 * Copyright 2003 Marco Ensing
 * Copyright 2004 Mns Tnneryd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */ 
package com.tanneryd.soapclipse.wsdl2java;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.dialogs.ContainerSelectionDialog;

/**
 * @author Andres Aguiar
 * @author Marco Ensing
 * @author Mns Tnneryd
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
public class WSDL2JavaWizardPage1 extends WizardPage
{
	private Combo comboTypeMapping;
	private Button chkSafePassword;
	private ISelection selection;
	private Text textContainer;
	private Text textFileNStoPkg;
	private Text textNStoPkg;
	private Text textPackage;
	private Text textPassword;
	private Text textTimeout;
	private Text textUser;
	private Text textWsdlUri;
	private IFile wsdlFile;

	private WSDL2JavaDialogSettings dialogSettings;

	public WSDL2JavaWizardPage1(
		WSDL2JavaDialogSettings dialogSettings,
		IFile wsdlFile)
	{
		super("Page1");
		this.dialogSettings = dialogSettings;
		this.wsdlFile = wsdlFile;

		setTitle("General settings");
		setDescription(
			"This wizard creates SOAP java stubs for a specified WSDL "
				+ "file using Apache Axis WSDL2Java.");
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
	 */
	public void createControl(Composite parent)
	{
		Composite container = new Composite(parent, SWT.NULL);
		GridLayout layout = new GridLayout();
		container.setLayout(layout);
		layout.numColumns = 4;
		layout.makeColumnsEqualWidth = true;
		layout.verticalSpacing = 8;

		addFileContainerItems(container);
		addWsdlUriItems(container);
		addTimeoutItems(container);
		addTypeMappingItems(container);
		addUsernamePasswordItems(container);
		addNStoPkgItems(container);

		loadSettings();
		validate();
		setControl(container);
	}

	/**
	 * 
	 */
	private void addFileContainerItems(Composite container)
	{
		Label label = new Label(container, SWT.NULL);
		label.setText("File &Container:");
		textContainer = new Text(container, SWT.BORDER | SWT.SINGLE);
		textContainer.setToolTipText("Select output folder for generated files.");
				
		GridData gd = new GridData();
		gd.horizontalAlignment = GridData.FILL;
		gd.horizontalSpan = 2;
		gd.grabExcessHorizontalSpace = true;
		textContainer.setLayoutData(gd);
		textContainer.addModifyListener(new ModifyListener()
		{
			public void modifyText(ModifyEvent e)
			{
				validate();
			}
		});

		Button button = new Button(container, SWT.PUSH);
		button.setText("Browse...");
		button.setToolTipText("Browse to existing output folder");
		button.setLayoutData(new GridData(GridData.END));
		button.addSelectionListener(new SelectionAdapter()
		{
			public void widgetSelected(SelectionEvent e)
			{
				handleBrowse();
			}
		});
	}

	/**
	 * 
	 */
	private void addWsdlUriItems(Composite container)
	{
		Label label = new Label(container, SWT.NULL);
		label.setText("URI to &WSDL:");
		textWsdlUri = new Text(container, SWT.BORDER | SWT.SINGLE);
		textWsdlUri.setText(wsdlFile.getLocation().toFile().toURI().toString());
		
		GridData gd = new GridData(GridData.FILL_HORIZONTAL);
		gd.horizontalSpan = 3;
		textWsdlUri.setLayoutData(gd);
		textWsdlUri.addModifyListener(new ModifyListener()
		{
			public void modifyText(ModifyEvent e)
			{
				validate();
			}
		});
	}

	private void addTimeoutItems(Composite container)
	{
		Label label = new Label(container, SWT.NULL);
		label.setText("Timeout in seconds");
		textTimeout = new Text(container, SWT.BORDER | SWT.SINGLE);
		textTimeout.setText("-1");
		GridData gd = new GridData(GridData.BEGINNING);
		gd.horizontalSpan = 3;
		gd.horizontalAlignment = GridData.HORIZONTAL_ALIGN_BEGINNING;
		textTimeout.setLayoutData(gd);
	}

	private void addTypeMappingItems(Composite container)
	{
		Label label = new Label(container, SWT.NULL);
		label.setText("Type mapping version:");
		comboTypeMapping = new Combo(container, SWT.READ_ONLY);
		GridData gd = new GridData(GridData.FILL_HORIZONTAL);
		gd.horizontalSpan = 3;
		gd.horizontalAlignment = GridData.HORIZONTAL_ALIGN_BEGINNING;
		comboTypeMapping.setItems(new String[] { "1.1", "1.2" });
		comboTypeMapping.setToolTipText(
			"Indicate 1.1 or 1.2.  The default is 1.2 (SOAP 1.2 JAX-RPC compliant).");
		comboTypeMapping.setLayoutData(gd);
		comboTypeMapping.select(0);
	}

	private void addUsernamePasswordItems(Composite container)
	{
		Label label = new Label(container, SWT.NULL);
		label.setText("User:");
		textUser = new Text(container, SWT.BORDER | SWT.SINGLE);
		textUser.setToolTipText(
			"This username is used in resolving the WSDL-URI provided as the input to WSDL2Java.");
		GridData gd = new GridData();
		gd.horizontalSpan = 2;
		gd.horizontalAlignment = GridData.FILL;
		gd.grabExcessHorizontalSpace = true;
		textUser.setLayoutData(gd);

		//dummy label
		label = new Label(container, SWT.NULL);
		label.setVisible(false);

		label = new Label(container, SWT.NULL);
		label.setText("Password:");
		textPassword = new Text(container, SWT.BORDER | SWT.SINGLE);
		textPassword.setEchoChar('*');
		textPassword.setToolTipText(
			"This password is used in resolving the WSDL-URI provided as the input to WSDL2Java.");
		gd = new GridData();
		gd.horizontalAlignment = GridData.FILL;
		gd.horizontalSpan = 2;
		gd.grabExcessHorizontalSpace = true;
		textPassword.setLayoutData(gd);
		chkSafePassword = new Button(container, SWT.CHECK);
		chkSafePassword.setLayoutData(new GridData(GridData.END));
		chkSafePassword.setText("Save password");
	}

	private void addNStoPkgItems(Composite container)
	{
		//Main label for the namespace to package mapping. Add a button in the end.

		/* Create a group for the image labels */
		Group grpNStoPkgGroup = new Group(container, SWT.NONE);
		grpNStoPkgGroup.setText("Mapping of namespace to package (NStoPkg)");
		GridData gd = new GridData();
		gd.horizontalAlignment = GridData.FILL;
		gd.horizontalSpan = 4;
		gd.grabExcessHorizontalSpace = true;
		grpNStoPkgGroup.setLayoutData(gd);

		GridLayout gridLayout = new GridLayout();
		gridLayout.numColumns = 2;
		grpNStoPkgGroup.setLayout(gridLayout);

		Label label = new Label(grpNStoPkgGroup, SWT.NULL);
		label.setText("Map NStoPkg:");
		textNStoPkg = new Text(grpNStoPkgGroup, SWT.BORDER | SWT.SINGLE);
		textNStoPkg.setToolTipText("example: urn:AddressFetcher2=samples.addr");
		gd = new GridData(GridData.FILL_HORIZONTAL);
		textNStoPkg.setLayoutData(gd);

		//gd.horizontalSpan = 3;
		label = new Label(grpNStoPkgGroup, SWT.NULL);
		label.setText("File of NStoPkg mappings:");
		textFileNStoPkg = new Text(grpNStoPkgGroup, SWT.BORDER | SWT.SINGLE);
		textFileNStoPkg.setToolTipText(
			"The entries in this file are of the same form as the arguments to the Map NStoPkg command line option.");
		gd = new GridData(GridData.FILL_HORIZONTAL);

		//gd.horizontalSpan = 3;
		textFileNStoPkg.setLayoutData(gd);

		label = new Label(grpNStoPkgGroup, SWT.NULL);
		label.setText("Map all to Pkg:");
		textPackage = new Text(grpNStoPkgGroup, SWT.BORDER | SWT.SINGLE);
		textPackage.setToolTipText(
			"map all namespaces in a WSDL document to same Java package");
		gd = new GridData(GridData.FILL_HORIZONTAL);

		//gd.horizontalSpan = 3;
		textPackage.setLayoutData(gd);

		grpNStoPkgGroup.pack();
	}

	/**
	 * Uses the standard container selection dialog to
	 * choose the new value for the container field.
	 */
	private void handleBrowse()
	{
		ContainerSelectionDialog dialog =
			new ContainerSelectionDialog(
				getShell(),
				ResourcesPlugin.getWorkspace().getRoot(),
				false,
				"Select new file container");

		if (dialog.open() == ContainerSelectionDialog.OK)
		{
			Object[] result = dialog.getResult();

			if (result.length == 1)
			{
				textContainer.setText(result[0].toString());
			}
		}
	}

	private void loadSettings()
	{
		chkSafePassword.setSelection(dialogSettings.isPasswordSafe());
		textTimeout.setText(Integer.toString(dialogSettings.getTimeout()));
		textNStoPkg.setText(dialogSettings.getNStoPkg());
		textFileNStoPkg.setText(dialogSettings.getFileNStoPkg());
		textPackage.setText(dialogSettings.getPackageName());
		comboTypeMapping.setText(dialogSettings.getTypeMappingVersion());
		textUser.setText(dialogSettings.getUser());
		textPassword.setText(dialogSettings.getPassword());

		String outputPath = wsdlFile.getFullPath().removeLastSegments(1).toString();
		String savedOutputPath = dialogSettings.getFileContainer();
		if ( savedOutputPath != null && !savedOutputPath.equals("") && !savedOutputPath.equals(outputPath))
			textContainer.setText(savedOutputPath);
		else
			textContainer.setText(outputPath);

//		textWsdlUri.setText(dialogSettings.getUrl());
	}

	public void storeSettings()
	{
		dialogSettings.setPasswordSafe(chkSafePassword.getSelection());
		dialogSettings.setTimeout(Integer.parseInt(textTimeout.getText()));
		dialogSettings.setNStoPkg(textNStoPkg.getText());
		dialogSettings.setFileNStoPkg(textFileNStoPkg.getText());
		dialogSettings.setPackageName(textPackage.getText());
		dialogSettings.setTypeMappingVersion(comboTypeMapping.getText());

		dialogSettings.setUser(textUser.getText());
		dialogSettings.setPassword(textPassword.getText());
		dialogSettings.setFileContainer(textContainer.getText());
		dialogSettings.setUrl(textWsdlUri.getText());
	}

	/**
	 * 
	 * 
	 */
	private void updateStatus(String message)
	{
		setErrorMessage(message);
		setPageComplete(message == null);
	}

	/**
	 * Ensures that both text fields are set.
	 */
	private void validate()
	{
		String container = textContainer.getText();
		String url = textWsdlUri.getText();
		if (container.length() == 0)
		{
			updateStatus("Output folder for generated files must be set.");
			return;
		}
		if (url.length() == 0)
		{
			updateStatus("Uri must be specified");
			return;
		}

		//updateStatus with null enables the next page 
		updateStatus(null);
	}
}
