/*
 * Copyright 2003 Andres Aguiar
 * Copyright 2003 Marco Ensing
 * Copyright 2004 Mns Tnneryd
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * 	http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */ 
package com.tanneryd.soapclipse.wsdl2java;

import org.eclipse.core.resources.IFile;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Combo;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

/**
 * @author Andres Aguiar
 * @author Marco Ensing
 * @author Mns Tnneryd
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
public class WSDL2JavaWizardPage2 extends WizardPage
{
	private WSDL2JavaWizard wizard;
	private Button chkAll;
	private Button chkHelperGen;
	private Button chkNoImports;
	private Button chkNoWrapped;
	private Button chkServerSide;
	private Button chkSkeletonDeploy;
	private Button chkTestCase;
	private Combo comboDeployScope;
	private Text textFactory;
	private Text implementationClassName;

	private WSDL2JavaDialogSettings dialogSettings;
	private IFile wsdlFile;

	public WSDL2JavaWizardPage2(
		WSDL2JavaDialogSettings dialogSettings,
		IFile wsdlFile)
	{
		super("Page2");
		this.dialogSettings = dialogSettings;
		this.wsdlFile = wsdlFile;

		setTitle("Advanced settings");
		setDescription(
			"This wizard creates SOAP java stubs for a specified WSDL "
				+ "file using Apache Axis WSDL2Java.");
	}

	/**
	 * @see IDialogPage#createControl(Composite)
	 */
	public void createControl(Composite parent)
	{
		this.wizard = (WSDL2JavaWizard) this.getWizard();

		Composite container = new Composite(parent, SWT.NULL);
		GridLayout layout = new GridLayout();
		container.setLayout(layout);
		layout.numColumns = 3;
		layout.verticalSpacing = 6;

		//Advanced option
		chkNoImports = new Button(container, SWT.CHECK);
		GridData gd = new GridData(GridData.FILL_HORIZONTAL);
		gd.horizontalSpan = 3;
		chkNoImports.setText(
			"Only generate code for the immediate WSDL document");
		chkNoImports.setLayoutData(gd);

		Label label = new Label(container, SWT.NULL);
		label.setText("Generator Factory class:");
		textFactory = new Text(container, SWT.BORDER | SWT.SINGLE);
		textFactory.setToolTipText(
			"Used to extend the functionality of the WSDL2Java emitter. The argument is the name of a class which extends JavaWriterFactory.");
		gd = new GridData(GridData.FILL_HORIZONTAL);
		gd.horizontalSpan = 2;
		textFactory.setLayoutData(gd);
		
		label = new Label(container, SWT.NULL);
		label.setText("Implementation class:");
		implementationClassName = new Text(container, SWT.BORDER | SWT.SINGLE);
		implementationClassName.setToolTipText(
			"Used to set the implementation class of the web service.");
		gd = new GridData(GridData.FILL_HORIZONTAL);
		gd.horizontalSpan = 2;
		implementationClassName.setLayoutData(gd);

		chkNoWrapped = new Button(container, SWT.CHECK);
		gd = new GridData(GridData.FILL_HORIZONTAL);
		gd.horizontalSpan = 3;
		chkNoWrapped.setText(
			"Turn off support for \"wrapped\" document/literal");
		chkNoWrapped.setLayoutData(gd);

		chkServerSide = new Button(container, SWT.CHECK);
		gd = new GridData(GridData.FILL_HORIZONTAL);
		gd.horizontalSpan = 3;
		chkServerSide.setText("Emit server-side bindings for web service");
		chkServerSide.setLayoutData(gd);

		chkSkeletonDeploy = new Button(container, SWT.CHECK);
		gd = new GridData(GridData.FILL_HORIZONTAL);
		gd.horizontalSpan = 3;
		chkSkeletonDeploy.setText("Deploy skeleton in deploy.wsdd");
		chkSkeletonDeploy.setLayoutData(gd);

		label = new Label(container, SWT.NULL);
		label.setText("Add scope to deploy.wsdd:");

		comboDeployScope = new Combo(container, SWT.READ_ONLY);
		gd = new GridData(GridData.FILL_HORIZONTAL);
		gd.horizontalSpan = 2;
		gd.horizontalAlignment = GridData.HORIZONTAL_ALIGN_BEGINNING;
		comboDeployScope.setItems(
			new String[] { "Application", "Request", "Session" });
		comboDeployScope.setLayoutData(gd);
		comboDeployScope.select(0);

		chkTestCase = new Button(container, SWT.CHECK);
		gd = new GridData(GridData.FILL_HORIZONTAL);
		gd.horizontalSpan = 3;
		chkTestCase.setText("Emit JUnit testcase class for web service");
		chkTestCase.setLayoutData(gd);

		chkAll = new Button(container, SWT.CHECK);
		gd = new GridData(GridData.FILL_HORIZONTAL);
		gd.horizontalSpan = 3;
		chkAll.setText(
			"Generate code for all elements, even unreferenced ones");
		chkAll.setLayoutData(gd);

		chkHelperGen = new Button(container, SWT.CHECK);
		gd = new GridData(GridData.FILL_HORIZONTAL);
		gd.horizontalSpan = 3;
		chkHelperGen.setText("Emit separate Helper classes for meta data");
		chkHelperGen.setLayoutData(gd);

		loadSettings();
		validate();
		setControl(container);
	}

	private void loadSettings()
	{
		chkNoImports.setSelection(dialogSettings.isNoImports());
		chkNoWrapped.setSelection(dialogSettings.isNoWrapped());
		if ( dialogSettings.getFactory() != null )
			textFactory.setText(dialogSettings.getFactory());
		if ( dialogSettings.getImplementationClassName() != null )
			implementationClassName.setText(dialogSettings.getImplementationClassName());
		chkServerSide.setSelection(dialogSettings.isServerSide());
		chkSkeletonDeploy.setSelection(dialogSettings.isSkeletonDeploy());
		comboDeployScope.setText(dialogSettings.getDeployScope());
		chkTestCase.setSelection(dialogSettings.isTestCase());
		chkAll.setSelection(dialogSettings.isAll());
		chkHelperGen.setSelection(dialogSettings.isHelperGen());
	}

	public void storeSettings()
	{
		dialogSettings.setNoImports(chkNoImports.getSelection());
		dialogSettings.setNoWrapped(chkNoWrapped.getSelection());
		dialogSettings.setFactory(textFactory.getText());
		dialogSettings.setImplementationClassName(implementationClassName.getText());
		dialogSettings.setServerSide(chkServerSide.getSelection());
		dialogSettings.setSkeletonDeploy(chkSkeletonDeploy.getSelection());
		dialogSettings.setDeployScope(comboDeployScope.getText());
		dialogSettings.setTestCase(chkTestCase.getSelection());
		dialogSettings.setAll(chkAll.getSelection());
		dialogSettings.setHelperGen(chkHelperGen.getSelection());
	}

	private void updateStatus(String message)
	{
		setErrorMessage(message);
		setPageComplete(message == null);
	}

	/**
	 * Ensures that both text fields are set.
	 */
	private void validate()
	{
		//updateStatus with null enables the next page 
		updateStatus(null);
	}
}
